==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwLjzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttFwLjz;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttFwLjzBdc extends KttFwLjz {
    private String dffwjg1dm;
    private String dffwjg1mc;
    private String dffwjg2dm;
    private String dffwjg2mc;
    private String dffwjg3dm;
    private String dffwjg3mc;
    private String dffwyt1dm;
    private String dffwyt1mc;
    private String dffwyt2dm;
    private String dffwyt2mc;
    private String dffwyt3dm;
    private String dffwyt3mc;
    @XmlAttribute(
            name = "DFFWJG1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg1dm() {
        return dffwjg1dm;
    }

    public void setDffwjg1dm(String dffwjg1dm) {
        this.dffwjg1dm = dffwjg1dm;
    }
    @XmlAttribute(
            name = "DFFWJG1MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg1mc() {
        return dffwjg1mc;
    }

    public void setDffwjg1mc(String dffwjg1mc) {
        this.dffwjg1mc = dffwjg1mc;
    }
    @XmlAttribute(
            name = "DFFWJG2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg2dm() {
        return dffwjg2dm;
    }

    public void setDffwjg2dm(String dffwjg2dm) {
        this.dffwjg2dm = dffwjg2dm;
    }
    @XmlAttribute(
            name = "DFFWJG2MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg2mc() {
        return dffwjg2mc;
    }

    public void setDffwjg2mc(String dffwjg2mc) {
        this.dffwjg2mc = dffwjg2mc;
    }
    @XmlAttribute(
            name = "DFFWJG3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg3dm() {
        return dffwjg3dm;
    }

    public void setDffwjg3dm(String dffwjg3dm) {
        this.dffwjg3dm = dffwjg3dm;
    }
    @XmlAttribute(
            name = "DFFWJG3MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwjg3mc() {
        return dffwjg3mc;
    }

    public void setDffwjg3mc(String dffwjg3mc) {
        this.dffwjg3mc = dffwjg3mc;
    }

    @XmlAttribute(
            name = "DFFWYT1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt1dm() {
        return dffwyt1dm;
    }

    public void setDffwyt1dm(String dffwyt1dm) {
        this.dffwyt1dm = dffwyt1dm;
    }
    @XmlAttribute(
            name = "DFFWYT1MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt1mc() {
        return dffwyt1mc;
    }

    public void setDffwyt1mc(String dffwyt1mc) {
        this.dffwyt1mc = dffwyt1mc;
    }
    @XmlAttribute(
            name = "DFFWYT2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt2dm() {
        return dffwyt2dm;
    }

    public void setDffwyt2dm(String dffwyt2dm) {
        this.dffwyt2dm = dffwyt2dm;
    }
    @XmlAttribute(
            name = "DFFWYT2MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt2mc() {
        return dffwyt2mc;
    }

    public void setDffwyt2mc(String dffwyt2mc) {
        this.dffwyt2mc = dffwyt2mc;
    }
    @XmlAttribute(
            name = "DFFWYT3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt3dm() {
        return dffwyt3dm;
    }

    public void setDffwyt3dm(String dffwyt3dm) {
        this.dffwyt3dm = dffwyt3dm;
    }
    @XmlAttribute(
            name = "DFFWYT3MC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDffwyt3mc() {
        return dffwyt3mc;
    }

    public void setDffwyt3mc(String dffwyt3mc) {
        this.dffwyt3mc = dffwyt3mc;
    }
}

==> estateplat-common-1.2.4-20220321.063855-990-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwLjzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttFwLjz;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttFwLjzBdc extends KttFwLjz {
    private String dffwjg1dm;
    private String dffwjg1mc;
    private String dffwjg2dm;
    private String dffwjg2mc;
    private String dffwjg3dm;
    private String dffwjg3mc;
    private String dffwyt1dm;
    private String dffwyt1mc;
    private String dffwyt2dm;
    private String dffwyt2mc;
    private String dffwyt3dm;
    private String dffwyt3mc;
    @XmlAttribute(
            name = "DFFWJG1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg1dm() {
        return dffwjg1dm;
    }

    public void setDffwjg1dm(String dffwjg1dm) {
        this.dffwjg1dm = dffwjg1dm;
    }
    @XmlAttribute(
            name = "DFFWJG1MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg1mc() {
        return dffwjg1mc;
    }

    public void setDffwjg1mc(String dffwjg1mc) {
        this.dffwjg1mc = dffwjg1mc;
    }
    @XmlAttribute(
            name = "DFFWJG2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg2dm() {
        return dffwjg2dm;
    }

    public void setDffwjg2dm(String dffwjg2dm) {
        this.dffwjg2dm = dffwjg2dm;
    }
    @XmlAttribute(
            name = "DFFWJG2MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg2mc() {
        return dffwjg2mc;
    }

    public void setDffwjg2mc(String dffwjg2mc) {
        this.dffwjg2mc = dffwjg2mc;
    }
    @XmlAttribute(
            name = "DFFWJG3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg3dm() {
        return dffwjg3dm;
    }

    public void setDffwjg3dm(String dffwjg3dm) {
        this.dffwjg3dm = dffwjg3dm;
    }
    @XmlAttribute(
            name = "DFFWJG3MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjg3mc() {
        return dffwjg3mc;
    }

    public void setDffwjg3mc(String dffwjg3mc) {
        this.dffwjg3mc = dffwjg3mc;
    }

    @XmlAttribute(
            name = "DFFWYT1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt1dm() {
        return dffwyt1dm;
    }

    public void setDffwyt1dm(String dffwyt1dm) {
        this.dffwyt1dm = dffwyt1dm;
    }
    @XmlAttribute(
            name = "DFFWYT1MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt1mc() {
        return dffwyt1mc;
    }

    public void setDffwyt1mc(String dffwyt1mc) {
        this.dffwyt1mc = dffwyt1mc;
    }
    @XmlAttribute(
            name = "DFFWYT2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt2dm() {
        return dffwyt2dm;
    }

    public void setDffwyt2dm(String dffwyt2dm) {
        this.dffwyt2dm = dffwyt2dm;
    }
    @XmlAttribute(
            name = "DFFWYT2MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt2mc() {
        return dffwyt2mc;
    }

    public void setDffwyt2mc(String dffwyt2mc) {
        this.dffwyt2mc = dffwyt2mc;
    }
    @XmlAttribute(
            name = "DFFWYT3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt3dm() {
        return dffwyt3dm;
    }

    public void setDffwyt3dm(String dffwyt3dm) {
        this.dffwyt3dm = dffwyt3dm;
    }
    @XmlAttribute(
            name = "DFFWYT3MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt3mc() {
        return dffwyt3mc;
    }

    public void setDffwyt3mc(String dffwyt3mc) {
        this.dffwyt3mc = dffwyt3mc;
    }
}
